@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import os
 from os.path import exists, isfile
 from UserList import UserList
 from itertools import chain
@@ -10,6 +11,7 @@ except ImportError:
 
 from srtitem import SubRipItem
 
+
 class SubRipFile(UserList, object):
     """
     SubRip file descriptor.
@@ -22,7 +24,7 @@ class SubRipFile(UserList, object):
         self._eol = eol
 
     def _get_eol(self):
-        return self._eol or DEFAULT_EOL
+        return self._eol or os.linesep
 
     def _set_eol(self, eol):
         self._eol = self._eol or eol
@@ -67,9 +69,10 @@ class SubRipFile(UserList, object):
     def from_string(cls, source):
         return cls.open(StringIO(source))
 
-    def slice(self, starts_before=None, starts_after=None, ends_before=None, ends_after=None):
+    def slice(self, starts_before=None, starts_after=None, ends_before=None,
+              ends_after=None):
         clone = copy(self)
-        
+
         if starts_before:
             clone.data = (i for i in clone.data if i.start < starts_before)
         if starts_after:
@@ -78,7 +81,7 @@ class SubRipFile(UserList, object):
             clone.data = (i for i in clone.data if i.end < ends_before)
         if ends_after:
             clone.data = (i for i in clone.data if i.end > ends_after)
-        
+
         clone.data = list(clone.data)
         return clone
 
@@ -96,7 +99,7 @@ class SubRipFile(UserList, object):
     def clean_ids(self):
         self.sort()
         for index, item in enumerate(self):
-            self[index].id = index + 1
+            item.id = index + 1
 
     def save(self, path=None, encoding=None, eol=None):
         """
@@ -112,5 +115,8 @@ class SubRipFile(UserList, object):
 
         save_file = open(path, 'w+')
         for item in self:
-            save_file.write(unicode(item).replace('\n', eol).encode(encoding))
+            string_repr = unicode(item)
+            if eol != self.eol:
+                string_repr = string_repr.replace(self.eol, eol)
+            save_file.write(string_repr.encode(encoding))
         save_file.close()
